@@ -3,8 +3,8 @@
  * License.....: MIT
  */
 
-#ifndef _MONITOR_H
-#define _MONITOR_H
+#ifndef HC_MONITOR_H
+#define HC_MONITOR_H
 
 #define STDIN_TIMEOUT_WARN 20 // warn if no input from stdin for x seconds
 
@@ -12,4 +12,4 @@ int get_runtime_left (const hashcat_ctx_t *hashcat_ctx);
 
 HC_API_CALL void *thread_monitor (void *p);
 
-#endif // _MONITOR_H
+#endif // HC_MONITOR_H
